/* SPEEDUP Path Integral Monte Carlo code is developed by A. Balaz,
   D. Stojiljkovic, I. Vidanovic, A. Belic, and A. Bogojevic.
         
   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/

   Public use and modification of this code is allowed providing 
   the authors are properly acknowledged. The authors would be   
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* Example p.c file for the model-specific approach for the anharmonic
   oscillator potential       
                        V(x) = A * x^2 / 2 + g * x^4 / 24

   Parameters: A = par[0], g = par[1], as entered on the command line.

   Maximal implemented level of the effective action is p = 30.
*/

/* This is the header for file p.c. */

#include <math.h>

/* Parameters of the potential, defined in main(), used in V0(). */
extern double *par;

/* Array with powers of 2 (two[n] = 2^n), defined in main(), used in func(). */
extern int *two;

/* Array of path integral norms, defined in main(), used in func(). */
extern double *norm;

/* Array of the exponents of Gaussian probability distribution functions,
   defined in distr(), used in func(). */
extern double *distrexp;

/* Variables calculated in function func() and used in function Wp(), for optimization purposes
   (powers of xbar, eps = T / N, g, A, x)
*/
double xbar, xbar2, xbar4, xbar6, xbar8, xbar10, xbar12, xbar14, xbar16, xbar18, xbar20, xbar22;
double eps, epsinv, eps2, eps3, eps4, eps5, eps6, eps7, eps8, eps9, eps10, eps11, eps12, eps13, eps14, eps15;
double eps16, eps17, eps18, eps19, eps20, eps21, eps22, eps23, eps24, eps25, eps26, eps27, eps28, eps29;
double g, g2, g3, g4, g5, g6, g7, g8, g9, g10, g11, g12, g13, g14, g15;
double A, A2, A3, A4, A5, A6, A7, A8, A9, A10, A11, A12, A13, A14, A15;
double x2, x4, x6, x8, x10, x12, x14, x16, x18, x20, x22, x24, x26, x28, x30, x32;

/* Variables used in the function func(). The variable x is the mid-point for a pair of points
   from the chosen path, variable action is the action for the given trajectory.
*/
double x, action;

/* Variables used in function func(). Variable Nmax = 2^s is the maximal number of time steps.
   Variable step is equal to 2^(s - n). In the bisection algorithm with Nmax = 2^s, paths are
   given by the arrays (q[0], ..., q[N]). If the current number of time steps is Nc = 2^n, the
   relevant paths are (q[0], q[step], ..., q[2^n step = Nmax]). 
*/
int Nmax, Nc, step;
