/* SPEEDUP Path Integral Monte Carlo code is developed by A. Balaz,
   D. Stojiljkovic, I. Vidanovic, A. Belic, and A. Bogojevic.
         
   Address: Institute of Physics, Belgrade, Serbia
   Scientific Computing Laboratory, http://www.scl.rs/

   Public use and modification of this code is allowed providing 
   the authors are properly acknowledged. The authors would be   
   grateful for all information and/or comments regarding the use   
   of the code.  
*/

/* Example p.h file for the model-specific approach for the modified
   P\"oschl-Teller potential  
                        V(x) = - c / cosh(a * x)^2
   Parameters: c = par[0], a = par[1], as entered on the command line.

   Maximal implemented level of the effective action is p = 10.
*/

/* This is the header for file p.c. */

#include <math.h>

/* Parameters of the potential, defined in main(), used in V0(). */
extern double *par;

/* Array with powers of 2 (two[n] = 2^n), defined in main(), used in func(). */
extern int *two;

/* Array of path integral norms, defined in main(), used in func(). */
extern double *norm;

/* Array of the exponents of Gaussian probability distribution functions,
   defined in distr(), used in func(). */
extern double *distrexp;

/* Variables calculated in function func() and used in function Wp(), for optimization purposes
   (powers of xbar, eps = T / N, c, a, tax = tanh(a * x), scx = sech(a * x)))
*/
double xbar, xbar2, xbar4, xbar6, xbar8, xbar10, xbar12, xbar14, xbar16, xbar18;
double eps, epsinv, eps2, eps3, eps4, eps5, eps6, eps7, eps8, eps9;
double c, c2, c3, c4, c5, a, a2, a4, a6, a8, a10, a12, a14, a16, a18;
double tax, tax2, tax4, tax6, tax8, tax10, tax12, tax14, tax16, tax18;
double scx, scx2, scx4, scx6, scx8, scx10, scx12, scx14, scx16, scx18, scx20;

/* Variables used in the function func(). The variable x is the mid-point for a pair of points
   from the chosen path, variable action is the action for the given trajectory.
*/
double x, action;

/* Variables used in function func(). Variable Nmax = 2^s is the maximal number of time steps.
   Variable step is equal to 2^(s - n). In the bisection algorithm with Nmax = 2^s, paths are
   given by the arrays (q[0], ..., q[N]). If the current number of time steps is Nc = 2^n, the
   relevant paths are (q[0], q[step], ..., q[2^n step = Nmax]). 
*/
int Nmax, Nc, step;
